Index: tools/gn/target_generator.cc |
diff --git a/tools/gn/target_generator.cc b/tools/gn/target_generator.cc |
index 084c587c9838ed0b5e7b5d513dcecf0fb6db3887..252d9822571c08eb7ad7afd350d2e7e1118cef8e 100644 |
--- a/tools/gn/target_generator.cc |
+++ b/tools/gn/target_generator.cc |
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() { |
void TargetGenerator::FillInputs() { |
const Value* value = scope_->GetValue(variables::kInputs, true); |
if (!value) { |
// Older versions used "source_prereqs". Allow use of this variable until |
// all callers are updated. |
// TODO(brettw) remove this eventually. |
- value = scope_->GetValue("source_prereqs", true); |
+ value = scope_->GetValue("inputs", true); |
if (!value) |
return; |
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() { |
const Value* value = scope_->GetValue(variables::kInputs, true); |
if (!value) { |
- // Older versions used "source_prereqs". Allow use of this variable until |
+ // Older versions used "inputs". Allow use of this variable until |
// all callers are updated. |
// TODO(brettw) remove this eventually. |